@@ -9,15 +9,15 @@ package org.mozilla.xpcom;
 
 public interface nsIXULChromeRegistry extends nsIChromeRegistry
 {
-  String NS_IXULCHROMEREGISTRY_IID =
+  public static final String NS_IXULCHROMEREGISTRY_IID =
     "{3e51f40b-b4b0-4e60-ac45-6c63477ebe41}";
 
-  void reloadChrome();
+  public void reloadChrome();
 
-  String getSelectedLocale(String arg1);
+  public String getSelectedLocale(String arg1);
 
-  void refreshSkins();
+  public void refreshSkins();
 
-  boolean allowScriptsForPackage(nsIURI arg1);
+  public boolean allowScriptsForPackage(nsIURI arg1);
 
 }
